@@ -1,9 +1,9 @@
 from __future__ import annotations
-import attr
 import kdsl.apiextensions.v1
+import attr
 import kdsl.core.v1
-from typing import Sequence, Optional, Any, Mapping, TypedDict, Union, Literal, ClassVar
-from kdsl.bases import K8sResource, OmitEnum, OMIT, K8sObject
+from typing import Any, Optional, Union, Literal, Mapping, Sequence, TypedDict, ClassVar
+from kdsl.bases import OMIT, K8sObject, OmitEnum, K8sResource
 
 
 def optional_list_converter_CustomResourceColumnDefinition(value: Union[Sequence[CustomResourceColumnDefinitionUnion], OmitEnum, None]) ->Union[Sequence[CustomResourceColumnDefinition], OmitEnum, None]:
