@@ -2,8 +2,8 @@ from __future__ import annotations
 import attr
 import kdsl.core.v1
 import kdsl.apps.v1
-from typing import Sequence, Optional, Any, Mapping, TypedDict, Union, Literal, ClassVar
-from kdsl.bases import K8sResource, OmitEnum, OMIT, K8sObject
+from typing import Any, Optional, Union, Literal, Mapping, Sequence, TypedDict, ClassVar
+from kdsl.bases import OMIT, K8sObject, OmitEnum, K8sResource
 
 
 def optional_mlist_converter_DaemonSetConditionItem(value: Union[Mapping[str, DaemonSetConditionItemUnion], OmitEnum, None]) ->Union[Mapping[str, DaemonSetConditionItem], OmitEnum, None]:
@@ -502,6 +502,7 @@ class StatefulSetSpec(K8sObject):
     selector: kdsl.core.v1.LabelSelector = attr.ib(metadata={'yaml_name': 'selector'}, converter=kdsl.core.v1.required_converter_LabelSelector)
     serviceName: str = attr.ib(metadata={'yaml_name': 'serviceName'})
     template: kdsl.core.v1.PodTemplateSpec = attr.ib(metadata={'yaml_name': 'template'}, converter=kdsl.core.v1.required_converter_PodTemplateSpec)
+    minReadySeconds: Union[None, OmitEnum, int] = attr.ib(metadata={'yaml_name': 'minReadySeconds'}, default=OMIT)
     podManagementPolicy: Union[None, OmitEnum, str] = attr.ib(metadata={'yaml_name': 'podManagementPolicy'}, default=OMIT)
     replicas: Union[None, OmitEnum, int] = attr.ib(metadata={'yaml_name': 'replicas'}, default=OMIT)
     revisionHistoryLimit: Union[None, OmitEnum, int] = attr.ib(metadata={'yaml_name': 'revisionHistoryLimit'}, default=OMIT)
@@ -510,6 +511,7 @@ class StatefulSetSpec(K8sObject):
 
 
 class StatefulSetSpecOptionalTypedDict(TypedDict, total=(False)):
+    minReadySeconds: int
     podManagementPolicy: str
     replicas: int
     revisionHistoryLimit: int
@@ -529,6 +531,7 @@ StatefulSetSpecUnion = Union[StatefulSetSpec, StatefulSetSpecTypedDict]
 @attr.s(kw_only=True)
 class StatefulSetStatus(K8sObject):
     replicas: int = attr.ib(metadata={'yaml_name': 'replicas'})
+    availableReplicas: Union[None, OmitEnum, int] = attr.ib(metadata={'yaml_name': 'availableReplicas'}, default=OMIT)
     collisionCount: Union[None, OmitEnum, int] = attr.ib(metadata={'yaml_name': 'collisionCount'}, default=OMIT)
     conditions: Union[None, OmitEnum, Mapping[str, kdsl.apps.v1.StatefulSetConditionItem]] = attr.ib(metadata={'yaml_name': 'conditions', 'mlist_key': 'type'}, converter=optional_mlist_converter_StatefulSetConditionItem, default=OMIT)
     currentReplicas: Union[None, OmitEnum, int] = attr.ib(metadata={'yaml_name': 'currentReplicas'}, default=OMIT)
@@ -540,6 +543,7 @@ class StatefulSetStatus(K8sObject):
 
 
 class StatefulSetStatusOptionalTypedDict(TypedDict, total=(False)):
+    availableReplicas: int
     collisionCount: int
     conditions: Mapping[str, kdsl.apps.v1.StatefulSetConditionItem]
     currentReplicas: int
