@@ -1,9 +1,9 @@
 from __future__ import annotations
+import kdsl.autoscaling.v2beta1
 import attr
 import kdsl.core.v1
-import kdsl.autoscaling.v2beta1
-from typing import Sequence, Optional, Any, Mapping, TypedDict, Union, Literal, ClassVar
-from kdsl.bases import OMIT, K8sResource, OmitEnum, K8sObject
+from typing import Any, Optional, Union, Literal, Mapping, Sequence, TypedDict, ClassVar
+from kdsl.bases import OmitEnum, OMIT, K8sResource, K8sObject
 
 
 def optional_list_converter_MetricSpec(value: Union[Sequence[MetricSpecUnion], OmitEnum, None]) ->Union[Sequence[MetricSpec], OmitEnum, None]:
