@@ -2,8 +2,8 @@ from __future__ import annotations
 import kdsl.autoscaling.v2beta2
 import attr
 import kdsl.core.v1
-from typing import Sequence, Optional, Any, Mapping, TypedDict, Union, Literal, ClassVar
-from kdsl.bases import K8sResource, OmitEnum, OMIT, K8sObject
+from typing import Any, Optional, Union, Literal, Mapping, Sequence, TypedDict, ClassVar
+from kdsl.bases import OmitEnum, OMIT, K8sResource, K8sObject
 
 
 def optional_list_converter_HPAScalingPolicy(value: Union[Sequence[HPAScalingPolicyUnion], OmitEnum, None]) ->Union[Sequence[HPAScalingPolicy], OmitEnum, None]:
