@@ -1,9 +1,9 @@
 from __future__ import annotations
+import kdsl.flowcontrol.v1beta1
 import attr
 import kdsl.core.v1
-import kdsl.flowcontrol.v1beta1
-from typing import Sequence, Optional, Any, Mapping, TypedDict, Union, ClassVar, Literal
-from kdsl.bases import K8sResource, OmitEnum, OMIT, K8sObject
+from typing import Any, Optional, Union, Mapping, Literal, Sequence, TypedDict, ClassVar
+from kdsl.bases import OMIT, K8sObject, OmitEnum, K8sResource
 
 
 def optional_list_converter_FlowSchemaCondition(value: Union[Sequence[FlowSchemaConditionUnion], OmitEnum, None]) ->Union[Sequence[FlowSchemaCondition], OmitEnum, None]:
