@@ -1,9 +1,9 @@
 from __future__ import annotations
+import kdsl.networking.v1
 import attr
 import kdsl.core.v1
-import kdsl.networking.v1
-from typing import Sequence, Optional, Any, Mapping, TypedDict, Union, ClassVar, Literal
-from kdsl.bases import K8sResource, OmitEnum, OMIT, K8sObject
+from typing import Any, Optional, Union, Literal, Mapping, Sequence, TypedDict, ClassVar
+from kdsl.bases import OMIT, K8sObject, OmitEnum, K8sResource
 
 
 def optional_list_converter_IngressRule(value: Union[Sequence[IngressRuleUnion], OmitEnum, None]) ->Union[Sequence[IngressRule], OmitEnum, None]:
@@ -203,17 +203,17 @@ def required_converter_ServiceBackendPort(value: ServiceBackendPortUnion) ->Serv
 @attr.s(kw_only=True)
 class HTTPIngressPath(K8sObject):
     backend: IngressBackend = attr.ib(metadata={'yaml_name': 'backend'}, converter=required_converter_IngressBackend)
+    pathType: str = attr.ib(metadata={'yaml_name': 'pathType'})
     path: Union[None, OmitEnum, str] = attr.ib(metadata={'yaml_name': 'path'}, default=OMIT)
-    pathType: Union[None, OmitEnum, str] = attr.ib(metadata={'yaml_name': 'pathType'}, default=OMIT)
 
 
 class HTTPIngressPathOptionalTypedDict(TypedDict, total=(False)):
     path: str
-    pathType: str
 
 
 class HTTPIngressPathTypedDict(HTTPIngressPathOptionalTypedDict, total=(True)):
     backend: IngressBackend
+    pathType: str
 
 
 HTTPIngressPathUnion = Union[HTTPIngressPath, HTTPIngressPathTypedDict]
