@@ -1,9 +1,9 @@
 from __future__ import annotations
+import kdsl.policy.v1beta1
 import attr
 import kdsl.core.v1
-import kdsl.policy.v1beta1
-from typing import Sequence, Optional, Any, Mapping, TypedDict, Union, ClassVar, Literal
-from kdsl.bases import K8sResource, OmitEnum, OMIT, K8sObject
+from typing import Any, Optional, Union, Mapping, Literal, Sequence, TypedDict, ClassVar
+from kdsl.bases import OMIT, K8sObject, OmitEnum, K8sResource
 
 
 def optional_list_converter_AllowedCSIDriver(value: Union[Sequence[AllowedCSIDriverUnion], OmitEnum, None]) ->Union[Sequence[AllowedCSIDriver], OmitEnum, None]:
@@ -429,14 +429,6 @@ class SupplementalGroupsStrategyOptionsTypedDict(TypedDict, total=(False)):
 SupplementalGroupsStrategyOptionsUnion = Union[SupplementalGroupsStrategyOptions, SupplementalGroupsStrategyOptionsTypedDict]
 
 
-@attr.s(kw_only=True)
-class Eviction(K8sResource):
-    apiVersion: ClassVar[str] = 'policy/v1beta1'
-    kind: ClassVar[str] = 'Eviction'
-    deleteOptions: Union[None, OmitEnum, kdsl.core.v1.DeleteOptions] = attr.ib(metadata={'yaml_name': 'deleteOptions'}, converter=kdsl.core.v1.optional_converter_DeleteOptions, default=OMIT)
-    metadata: Union[None, OmitEnum, kdsl.core.v1.ObjectMeta] = attr.ib(metadata={'yaml_name': 'metadata'}, converter=kdsl.core.v1.optional_converter_ObjectMeta, default=OMIT)
-
-
 @attr.s(kw_only=True)
 class PodDisruptionBudget(K8sResource):
     apiVersion: ClassVar[str] = 'policy/v1beta1'
