@@ -1,8 +1,8 @@
 from __future__ import annotations
 import attr
 import kdsl.core.v1
-from typing import Sequence, Optional, Any, Union, ClassVar, Mapping, TypedDict
-from kdsl.bases import OMIT, K8sResource, OmitEnum, K8sObject
+from typing import Mapping, Any, Optional, Sequence, TypedDict, Union, ClassVar
+from kdsl.bases import OmitEnum, OMIT, K8sResource, K8sObject
 
 
 @attr.s(kw_only=True)
